import requests

SR = "https://some-random-api.ml"

class Pokemon:
	def __init__(self , pokemon_json):
		self.json = pokemon_json
		self.stats = self.json['stats']
		self.family = self.json['family']

	@property
	def name(self):
		return self.json['name']

	@property
	def id_(self):
		return self.json['id']

	@property
	def type(self):
		return self.json['type']
	
	@property
	def species(self):
		return self.json['species']

	@property
	def image_url(self):
		return self.json['sprites']['normal']

	@property
	def gif_url(self):
		return self.json['sprites']['animated']
	
	@property
	def weight(self):
		return self.json['weight']

	@property
	def height(self):
		return self.json['height']

	@property
	def gender(self):
		return self.json['gender']

	@property
	def description(self):
		return self.json['description']

	@property
	def generation(self):
		return self.json['generation']

	@property
	def abilities(self):
		return self.json['abilities']

	@property
	def base_experience(self):
		return self.json['base_experience']

	@property
	def hp(self):
		return self.stats['hp']

	@property
	def attack(self):
		return self.stats['attack']
	
	@property
	def defence(self):
		return self.stats['defence']

	@property
	def speed(self):
		return self.stats['speed']

	@property
	def sp_attack(self):
		return self.stats['sp_atk']
	
	@property
	def sp_defence(self):
		return self.stats['sp_def']

	@property
	def total(self):
		return self.stats['total']

	@property
	def egg_groups(self):
		return self.json['egg_groups']

	@property
	def evolution_stage(self):
		return self.family['evolutionStage']

	@property
	def evolution_line(self):
		return self.family['evolutionLine']

def pokedex(pokemon):
	r = requests.request("GET", f"{SR}/pokedex?pokemon={pokemon}").json()
	print(r)
	return Pokemon(r)


'''
A python wrapper for some-random-api

https://some-random-api.ml
'''

from .images import *
from .anime import *
from .fun import *
from .pokemon import *
from .facts import *
from .canvas import *


import requests

SR = "https://some-random-api.ml"

class GIF:
	def __init__(self , gif_json):
		self.json = gif_json

	@property
	def gif_url(self):
		return self.json['link']

	def save(self):
		try:
			filename = self.gif_url.split('/')[-1]
			r = requests.get(self.gif_url , allow_redirects = True)
			open(filename , 'wb').write(r.content)
			return True
		except:
			return False

def wink():
	r = requests.request("GET", f"{SR}/wink").json()
	return GIF(r)

def pat():
	r = requests.request("GET", f"{SR}/pat").json()
	return GIF(r)

def hug():
	r = requests.request("GET", f"{SR}/hug").json()
	return GIF(r)


from .errors import *

import requests

SR = "https://some-random-api.ml"

class Image:
	def __init__(self , image_url: str):
		self.image_url_ = image_url

	@property
	def image_url(self):
		return self.image_url_

	def save(self):
		try:
			filename = self.image_url.split('/')[-1]
			r = requests.get(self.image_url , allow_redirects = True)
			open(filename , 'wb').write(r.content)
			return True
		except:
			return False
	

def image(endpoint: str):
	try:
		r = requests.request("GET", f"{SR}/img/{endpoint}").json()
		return r["link"]
	except:
		raise NotFound(f"Endpoint \"{endpoint}\" not found")

def dog():
	return image('dog')

def cat():
	return image('cat')

def fox():
	return image('fox')

def panda():
	return image('panda')

def red_panda():
	return image('red_panda')

def bird():
	return image('birb')

def koala():
	return image('koala')

def pikachu():
	return image('pikachu')

def kangaroo():
	return image('kangaroo')

def racoon():
	return image('racoon')

def whale():
	return image('whale')


import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="sra_py",
    version="1.2",
    author="Atidipt123",
    author_email = "atidiptmishra@gmail.com",
    description="Python wrapper for some-random-api.ml",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Atidipt123/sra_py",
    download_url = "https://github.com/Atidipt123/sra_py/archive/refs/tags/v0.1.3.tar.gz",
    project_urls={
        "Bug Tracker": "https://github.com/Atidipt123/sra_py/issues",
    },
    package_dir={"": "sra_py"},
    packages=setuptools.find_packages(where='sra_py'),
    install_requires=['requests' , 'aiohttp']
)


import requests

SR = "https://some-random-api.ml"

class Meme():
	def __init__(self , meme_: dict):
		self.caption_ = meme_['caption']
		self.category_ = meme_['category']
		self.image_url_ = meme_['image']
		self.id__ = meme_['id']

	@property
	def image_url(self):
		return self.image_url_

	@property
	def category(self):
		return self.category_

	@property
	def caption(self):
		return self.caption_

	@property
	def id_(self):
		return self.id__

	def save(self , filename=None):
		try:
			if filename is None:
				filename = self.image_url.split('/')[-1]
			r = requests.get(self.image_url , allow_redirects = True)
			open(filename , 'wb').write(r.content)
			return True
		except:
			return False

def meme():
	r = requests.request("GET", f"{SR}/meme").json()
	return Meme(r)

def joke():
	r = requests.request("GET", f"{SR}/joke").json()
	return r['joke']

def base64(text: str , mode):
	text = text.replace(' ', '%20')

	if mode == "encode":
		r = requests.request("GET", f"{SR}/base64?encode={text}").json()
		return r['base64']

	elif mode == "decode":
		r = requests.request("GET", f"{SR}/base64?decode={text}").json()
		return r['base64']

	else:
		raise NotFound("Invalid Mode")

def chat_bot(key , message):
	r = requests.request("GET", f"{SR}/chatbot?message={message}&key={key}").json()
	return r

def minecraft(username):
	r = requests.request("GET", f"{SR}/mc?username={username}").json()
	return r

def bot_token(id_=None):
	if id_ is None:
		r = requests.request("GET", f"{SR}/bottoken").json()
		return r['token']
	else:
		try:
			r = requests.request("GET", f"{SR}/bottoken?id={id_}").json()
			return r['token']
		except:
			raise NotFound("Invalid ID")

def lyrics(title: str):
	title = title.replace(' ', '%20')
	r = requests.request("GET", f"{SR}/lyrics?title={title}").json()
	return r


import requests
import io
import aiohttp

SR = "https://some-random-api.ml/canvas/"

async def invert(avatar_url: str):
	async with aiohttp.ClientSession() as se:
		async with se.get(f"https://some-random-api.ml/canvas/invert?avatar={avatar_url}") as img:
			im = io.BytesIO(await img.read())
			await se.close()

	return im

async def wasted(avatar_url: str):
	async with aiohttp.ClientSession() as se:
		async with se.get(f"https://some-random-api.ml/canvas/wasted?avatar={avatar_url}") as img:
			im = io.BytesIO(await img.read())
			await se.close()

	return im

async def jail(avatar_url: str):
	async with aiohttp.ClientSession() as se:
		async with se.get(f"https://some-random-api.ml/canvas/jail?avatar={avatar_url}") as img:
			im = io.BytesIO(await img.read())
			await se.close()

	return im

async def mission_passed(avatar_url: str):
	async with aiohttp.ClientSession() as se:
		async with se.get(f"https://some-random-api.ml/canvas/passed?avatar={avatar_url}") as img:
			im = io.BytesIO(await img.read())
			await se.close()

	return im

async def glass(avatar_url: str):
	async with aiohttp.ClientSession() as se:
		async with se.get(f"https://some-random-api.ml/canvas/glass?avatar={avatar_url}") as img:
			im = io.BytesIO(await img.read())
			await se.close()

	return im

async def comrade(avatar_url: str):
	async with aiohttp.ClientSession() as se:
		async with se.get(f"https://some-random-api.ml/canvas/comrade?avatar={avatar_url}") as img:
			im = io.BytesIO(await img.read())
			await se.close()

	return im

async def simpcard(avatar_url: str):
	async with aiohttp.ClientSession() as se:
		async with se.get(f"https://some-random-api.ml/canvas/simpcard?avatar={avatar_url}") as img:
			im = io.BytesIO(await img.read())
			await se.close()

	return im

async def blur(avatar_url: str):
	async with aiohttp.ClientSession() as se:
		async with se.get(f"https://some-random-api.ml/canvas/blur?avatar={avatar_url}") as img:
			im = io.BytesIO(await img.read())
			await se.close()

	return im

async def pixelate(avatar_url: str):
	async with aiohttp.ClientSession() as se:
		async with se.get(f"https://some-random-api.ml/canvas/pixelate?avatar={avatar_url}") as img:
			im = io.BytesIO(await img.read())
			await se.close()

	return im